# -*- coding: utf-8 -*-
BOT_NAME = 'ilmwetter'

SPIDER_MODULES = ['ilmwetter.spiders']
NEWSPIDER_MODULE = 'ilmwetter.spiders'
METAREFRESH_ENABLED = False
DEFAULT_ITEM_CLASS = 'ilmwetter.items.IlmwetterItem'

ITEM_PIPELINES = {
    'ilmwetter.pipelines.IlmwetterPipeline': 100
}



# -*- coding: utf-8 -*-
from datetime import datetime


class IlmwetterPipeline(object):
    @staticmethod
    def process_float(item, attr):
        item[attr] = float(item[attr][1].split()[0])

    def process_item(self, item, spider):
        timetext = item["scraping_time"][0]
        raw_date, raw_time = timetext.split("am")[1].split("um")
        int_dates = map(int, raw_date.split("."))
        int_dates.reverse()
        int_times = map(int, raw_time.split(":")[:2])
        item["scraping_time"] = datetime(*(int_dates + int_times))

        for attr in ("temperature", "humidity", "dew_point", "pressure",
                     "wind_direction", "wind_speed", "solar_radiation",
                     "precipitation_amount"):
            self.process_float(item, attr)

        return item



# -*- coding: utf-8 -*-
import scrapy


class IlmwetterItem(scrapy.Item):
    dew_point = scrapy.Field()
    humidity = scrapy.Field()
    precipitation_amount = scrapy.Field()
    pressure = scrapy.Field()
    scraping_time = scrapy.Field()
    solar_radiation = scrapy.Field()
    temperature = scrapy.Field()
    wind_direction = scrapy.Field()
    wind_speed = scrapy.Field()



# -*- coding: utf-8 -*-
import scrapy

from ..items import IlmwetterItem


class ThedySpider(scrapy.Spider):
    name = "thedy"
    allowed_domains = [
        "http://www.thedy22.maschinenbau.tu-ilmenau.de/wwwtd/WISI/WISI02.php"]
    start_urls = (
        'http://thedy22.maschinenbau.tu-ilmenau.de/wwwtd/WISI/WISI02.php/',  # noqa
    )

    @staticmethod
    def extract_by_text(response, text):
        return response.xpath("//td[contains(text(), '{text}')]/text()".
                              format(text=text)).\
                              extract()

    @staticmethod
    def extract_by_href(response, text):
        return response.xpath("//a[contains(@href, '{href}')]/text()".
                              format(href=text)).\
                              extract()

    def parse(self, response):
        item = IlmwetterItem()
        item["dew_point"] = self.extract_by_href(response, "taupunkt")
        item["humidity"] = self.extract_by_href(response, "luftfeucht")
        item["precipitation_amount"] = self.extract_by_text(response,
                                                            "Niederschlagsmenge")  # noqa
        item["pressure"] = self.extract_by_text(response, "Luftdruck")
        item["scraping_time"] = self.extract_by_href(response, "GMT")
        item["solar_radiation"] = self.extract_by_text(response,
                                                       "Globalstrahlung")
        item["temperature"] = self.extract_by_text(response, "Lufttemperatur")
        item["wind_direction"] = self.extract_by_text(response, "Windrichtung")
        item["wind_speed"] = self.extract_by_text(response,
                                                  "Windgeschwindigkeit")
        yield item



from setuptools import setup, find_packages

setup(
    name             = 'ilmwetter',
    version          = '0.2',
    packages         = find_packages(),
    entry_points     = {'scrapy': ['settings = ilmwetter.settings']},
    description      = "Scrapy spider for the weather in Ilmenau",
    author           = "Wieland Hoffmann",
    install_requires = ["scrapy"],
    url              = "https://github.com/mineo/ilmwetter",
    download_url     = ["https://github.com/mineo/ilmwetter/tarball/master"],
    license          = "MIT",
    classifiers      = ["Development Status :: 4 - Beta",
                        "Environment :: Console",
                        "Framework :: Twisted",
                        "License :: OSI Approved :: MIT License",
                        "Natural Language :: English",
                        "Operating System :: OS Independent",
                        "Programming Language :: Python :: 2.7"],
)
